# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`pdsh`](#pdsh): Manage pdsh

#### Private Classes

* `pdsh::config`: Manage pdsh config
* `pdsh::install`: Install pdsh

### Defined types

* [`pdsh::group`](#pdshgroup): Define pdsh groups

## Classes

### <a name="pdsh"></a>`pdsh`

Manage pdsh

#### Examples

##### 

```puppet
include ::pdsh
```

#### Parameters

The following parameters are available in the `pdsh` class:

* [`with_rsh`](#with_rsh)
* [`with_ssh`](#with_ssh)
* [`with_genders`](#with_genders)
* [`with_slurm`](#with_slurm)
* [`support_dsh`](#support_dsh)
* [`manage_epel`](#manage_epel)
* [`manage_genders`](#manage_genders)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`rsh_package_name`](#rsh_package_name)
* [`ssh_package_name`](#ssh_package_name)
* [`dshgroup_package_name`](#dshgroup_package_name)
* [`genders_package_name`](#genders_package_name)
* [`slurm_package_name`](#slurm_package_name)
* [`extra_packages`](#extra_packages)
* [`dsh_config_dir`](#dsh_config_dir)
* [`dsh_group_dir`](#dsh_group_dir)
* [`dsh_group_dir_purge`](#dsh_group_dir_purge)
* [`groups`](#groups)
* [`use_setuid`](#use_setuid)
* [`rcmd_type`](#rcmd_type)
* [`ssh_args_append`](#ssh_args_append)

##### <a name="with_rsh"></a>`with_rsh`

Data type: `Boolean`

Install rsh support

Default value: ``false``

##### <a name="with_ssh"></a>`with_ssh`

Data type: `Boolean`

Install ssh support

Default value: ``true``

##### <a name="with_genders"></a>`with_genders`

Data type: `Boolean`

Install genders support

Default value: ``false``

##### <a name="with_slurm"></a>`with_slurm`

Data type: `Boolean`

Install SLURM support

Default value: ``false``

##### <a name="support_dsh"></a>`support_dsh`

Data type: `Boolean`

Boolean to set if dsh support is available

Default value: ``true``

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

Boolean that determines if EPEL repo should be managed

Default value: ``true``

##### <a name="manage_genders"></a>`manage_genders`

Data type: `Boolean`

Boolean that determines if genders class should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Packages ensure property

Default value: `'present'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Main pdsh package name

Default value: `'pdsh'`

##### <a name="rsh_package_name"></a>`rsh_package_name`

Data type: `Optional[String]`

rsh support package name

Default value: ``undef``

##### <a name="ssh_package_name"></a>`ssh_package_name`

Data type: `Optional[String]`

ssh support package name

Default value: ``undef``

##### <a name="dshgroup_package_name"></a>`dshgroup_package_name`

Data type: `Optional[String]`

dshgroup support package name

Default value: ``undef``

##### <a name="genders_package_name"></a>`genders_package_name`

Data type: `Optional[String]`

Genders support package name

Default value: ``undef``

##### <a name="slurm_package_name"></a>`slurm_package_name`

Data type: `Optional[String]`

SLURM support package name

Default value: ``undef``

##### <a name="extra_packages"></a>`extra_packages`

Data type: `Array`

Additional pdsh packages to install

Default value: `[]`

##### <a name="dsh_config_dir"></a>`dsh_config_dir`

Data type: `Stdlib::Absolutepath`

Path to dsh config directory

Default value: `'/etc/dsh'`

##### <a name="dsh_group_dir"></a>`dsh_group_dir`

Data type: `Stdlib::Absolutepath`

Path to dsh group directory

Default value: `'/etc/dsh/group'`

##### <a name="dsh_group_dir_purge"></a>`dsh_group_dir_purge`

Data type: `Boolean`

Sets if dsh group directory should be purged

Default value: ``true``

##### <a name="groups"></a>`groups`

Data type: `Variant[Array, Hash]`

Groups that should be defined using `pdsh::group`

Default value: `{}`

##### <a name="use_setuid"></a>`use_setuid`

Data type: `Boolean`

Should pdsh binaries have setuid

Default value: ``false``

##### <a name="rcmd_type"></a>`rcmd_type`

Data type: `Optional[String]`

Sets default remote command via `PDSH_RCMD_TYPE` environment variable

Default value: ``undef``

##### <a name="ssh_args_append"></a>`ssh_args_append`

Data type: `Optional[String]`

Additional SSH arguments set via `PDSH_SSH_ARGS_APPEND` environment variable

Default value: ``undef``

## Defined types

### <a name="pdshgroup"></a>`pdsh::group`

Define pdsh groups

#### Examples

##### 

```puppet
pdsh::group { 'nodes':
  members => 'c[01-04]',
  aliases => 'compute',
}
```

#### Parameters

The following parameters are available in the `pdsh::group` defined type:

* [`aliases`](#aliases)
* [`members`](#members)

##### <a name="aliases"></a>`aliases`

Data type: `Variant[Array, String]`

Group aliases

Default value: `[]`

##### <a name="members"></a>`members`

Data type: `Variant[Array, String]`

Group members

Default value: `[]`

